<?php
/**
 * Acuarela back compat functionality
 *
 * Prevents Acuarela from running on WordPress versions prior to 4.9,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.9.
 *
 * @package Acuarela
 * @since Acuarela 1.0
 */

/**
 * Prevent switching to Acuarela on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since Acuarela 1.0
 */
function acuarela_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );

	unset( $_GET['activated'] );

	add_action( 'admin_notices', 'acuarela_upgrade_notice' );
}
add_action( 'after_switch_theme', 'acuarela_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Acuarela on WordPress versions prior to 4.9.
 *
 * @since Acuarela 1.0
 *
 * @global string $wp_version WordPress version.
 */
function acuarela_upgrade_notice() {
	$message = sprintf( __( 'Acuarela requires at least WordPress version 4.9. You are running version %s. Please upgrade and try again.', 'acuarela' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.9.
 *
 * @since Acuarela 1.0
 *
 * @global string $wp_version WordPress version.
 */
function acuarela_customize() {
	wp_die( sprintf( __( 'Acuarela requires at least WordPress version 4.9. You are running version %s. Please upgrade and try again.', 'acuarela' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'acuarela_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.9.
 *
 * @since Acuarela 1.0
 *
 * @global string $wp_version WordPress version.
 */
function acuarela_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'Acuarela requires at least WordPress version 4.9. You are running version %s. Please upgrade and try again.', 'acuarela' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'acuarela_preview' );
