<?php
/**
 * Custom template tags for Acuarela
 *
 * @package Acuarela
 * @since Acuarela 1.0
 */

/**
 * Prints Acuarela's custom logo markup.
 *
 * @since Acuarela 1.0
 */
function acuarela_the_custom_logo() {
	$html = sprintf( '<a href="%1$s" class="custom-logo-link home-link" rel="home" itemprop="url"><div class="logo-box"><img class="custom-logo" src="%2$s" alt="logo"></div><div class="title-description"><h1 class="site-title">%3$s</h1><h2 class="site-description">%4$s</h2></div></a>',
		esc_url( home_url( '/' ) ),
		esc_attr( wp_get_attachment_image_url( get_theme_mod( 'custom_logo' ), 'full' ) ),
		esc_html( get_bloginfo( 'name' ) ) ,
		esc_html( get_bloginfo( 'description' ) )
	);
	return $html;
}
add_filter( 'get_custom_logo', 'acuarela_the_custom_logo' );

function acuarela_category_list() {
	get_the_category_list( __( ', ', 'acuarela' ) );
}
add_filter( 'get_the_category_list', 'acuarela_category_list' );

/**
 * Prints the entry footer markup in index/archive pages.
 *
 * @since Acuarela 1.0
 */
function acuarela_entry_footer() { ?>
	<footer class="entry-footer">
		<div class="entry-meta">
		<?php
		printf( '<a href="%1$s" class="entry-date" rel="bookmark"><span class="screen-reader-text"> %2$s</span><span class="genericon genericon-time" aria-hidden="true"></span><time datetime="%3$s">%4$s</time></a>',
			esc_url( get_permalink() ),
			esc_html( get_the_title() ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);

		// Translators: used between list items, there is a space after the comma.
		$tag_list = get_the_tag_list( '', __( ', ', 'acuarela' ) );
		if ( $tag_list ) {
			echo '<span class="tags-links"><span class="genericon genericon-tag" aria-hidden="true"></span>' . $tag_list . '</span>';
		}

		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) : ?>
			<span class="comments-link">
				<span class="genericon genericon-comment" aria-hidden="true"></span>
				<?php acuarela_comments_popup_link(); ?>
			</span>
		<?php endif; ?>
			
		</div><!-- .entry-meta -->
	</footer><!-- .entry-footer -->
<?php }

if ( ! function_exists( 'acuarela_archive_title' ) ) :
	/**
	 * Prints the_archive_title() and the_archive_description().
	 *
	 * @since Acuarela 1.0
	 */

	function acuarela_archive_title() { ?>
		<header class="page-header">
		<?php
			the_archive_title( '<h1 class="page-title">', '</h1>' );
			the_archive_description( '<div class="archive-description">', '</div>' );
		?>
		</header><!-- .page-header -->
<?php }
endif;

if ( ! function_exists( 'acuarela_post_navigation' ) ) :
	/**
	 * Prints the markup for the navigation between posts and changes the default strings of the_post_navigation().
	 *
	 * @since Acuarela 1.0
	 */
	function acuarela_post_navigation() {
		the_post_navigation( array(
			'next_text' => '<span class="post-title">%title</span><span class="screen-reader-text">' . __( 'Next post:', 'acuarela' ) . '</span> <span class="genericon genericon-next" aria-hidden="true"></span> ',
			'prev_text' => '<span class="genericon genericon-previous" aria-hidden="true"></span> <span class="screen-reader-text">' . __( 'Previous post:', 'acuarela' ) . '</span> <span class="post-title">%title</span>',
		) );
	}
endif;

if ( ! function_exists( 'acuarela_blog_navigation' ) ) :
	/**
	 * Applies the user's choice for navigation/pagination and changes the default strings in the_posts_navigation() and the_posts_pagination().
	 *
	 * @since Acuarela 1.0
	 */
	function acuarela_blog_navigation() {
		$acuarela_theme_options = acuarela_get_options( 'acuarela_theme_options' );
		if ( $acuarela_theme_options['blog_navigation'] == 'navigation' ) :
			the_posts_navigation( array(
				'prev_text' => '<span class="genericon genericon-previous" aria-hidden="true"></span><span>' . __( 'Older articles', 'acuarela' ) . '</span>',
				'next_text' => '<span>' . __( 'Newer articles', 'acuarela' ) . '</span><span class="genericon genericon-next" aria-hidden="true"></span>',
			) );
		else :
			the_posts_pagination( array(
				'prev_text' => '<span class="genericon genericon-previous" aria-hidden="true"></span><span class="screen-reader-text">' . __( 'Previous page', 'acuarela' ) . '</span>',
				'next_text' => '<span class="screen-reader-text">' . __( 'Next page', 'acuarela' ) . '</span><span class="genericon genericon-next" aria-hidden="true"></span>',
				'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'acuarela' ) . ' </span>',
			) );
		endif;
	}
endif;

if ( ! function_exists( 'acuarela_comments_navigation' ) ) :
	/**
	 * Prints custom html markup for the_comments_navigation()
	 *
	 * @since Acuarela 1.0
	 */
	function acuarela_comments_navigation() {
		the_comments_navigation( array(
			'prev_text' => '<span class="genericon genericon-previous" aria-hidden="true"></span> ' . __( 'Older', 'acuarela' ),
			'next_text' => __( 'Newer', 'acuarela' ) . ' <span class="genericon genericon-next" aria-hidden="true"></span>',
		));
	}
endif;

if ( ! function_exists( 'acuarela_comments_popup_link' ) ) :
	/**
	 * Prints the markup for the navigation between posts and changes the default strings of the_post_navigation().
	 *
	 * @since Acuarela 1.0
	 */
	function acuarela_comments_popup_link() {
		comments_popup_link(
			// Translators: there is a space after "on.
			'<span aria-hidden="true">0</span><span class="screen-reader-text">' . __( 'No comments on ', 'acuarela' ) . get_the_title() . '</span>',
			// Translators: there is a space after "on.
			'<span aria-hidden="true">1</span><span class="screen-reader-text">' . __( 'Only one comment on ', 'acuarela' ) . get_the_title() . '</span>',
			// Translators: there is a space after "on.
			'<span aria-hidden="true">%</span><span class="screen-reader-text">' . __( '% comments on ', 'acuarela' ) . get_the_title() . '</span>'
		);
	}
endif;

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ...
 * and a Continue reading link.
 *
 * @since Acuarela 1.0
 *
 * @param string $more Default Read More excerpt link.
 * @return string Filtered Read More excerpt link.
 */
function acuarela_excerpt_more( $more ) {
	if ( ! is_single() ) {
		$link = sprintf( '<a href="%1$s" class="more-link">%2$s</a>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* Translators: %s: Name of current post */
			sprintf( __( 'More', 'acuarela' ) . ' %s <span class="meta-nav">&rarr;</span>', '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>' )
		);
		return ' &hellip; ' . $link;
	} else {
		return '. ';
	}
}
add_filter( 'excerpt_more', 'acuarela_excerpt_more' );

/**
 * Filter the except length to 20 characters.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
function acuarela_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'acuarela_excerpt_length', 999 );

/**
 * Filters the edit comment link.
 */
function acuarela_edit_comment_link() {
	$link = sprintf( '<a href="%1$s" class="comment-edit-link"><span class="genericon genericon-edit" aria-hidden="true"></span>%2$s</a>',
		esc_url( get_edit_comment_link() ),
		esc_html( __( 'Edit', 'acuarela' ) )
	);

	return $link;
}
add_filter( 'edit_comment_link', 'acuarela_edit_comment_link' );


